@@ -1,6 +1,6 @@
 from .main import run, Effect, Strand, TapystryError
 
-from .main import Broadcast, Receive, CallFork, First, Call, Cancel, CallThread, Intercept, DebugTree
+from .main import Broadcast, Receive, CallFork, First, Call, Cancel, CallThread, Intercept, DebugTree, Wrapper
 from .utils import as_effect, runnable
 from .effects import Sequence, Fork, Join, Race, Subscribe, Sleep
 from .concurrency import Lock, Queue
